@@ -168,10 +168,6 @@ Padre,app-editors/padre
 PathTools,virtual/perl-File-Spec
 Regexp-Common,dev-perl/regexp-common
 Snapback2,app-backup/snapback2
-Text-Template,dev-perl/text-template
-Text-Wrapper,dev-perl/text-wrapper
-Tie-EncryptedHash,dev-perl/tie-encryptedhash
 XML-XSH2,app-editors/XML-XSH2
-YAML,dev-perl/yaml
 ack,sys-apps/ack
 gettext,dev-perl/Locale-gettext
